'use strict';

const ky = require('ky-universal');

function getToken(project) {
  switch (project) {
    case 'carrier':
      return process.env.SENDGRID_CTMS_TOKEN;
    case 'shipper':
      return process.env.SENDGRID_STMS_TOKEN;
    case 'customer_portal':
      return process.env.SENDGRID_CP_TOKEN;
    case 'loadboard':
      return process.env.SENDGRID_SLB_TOKEN;
    default:
      throw new Error(`SendGrid token not found for project "${project}".`);
  }
}

class SendGridAPI {
  constructor(project) {
    this.request = (url, { headers, ...options } = {}) =>
      ky(url, {
        ...options,
        prefixUrl: 'https://api.sendgrid.com/v3',
        headers: {
          ...headers,
          Authorization: `Bearer ${getToken(project)}`,
        },
      }).json();
  }

  createTemplateVersion({
    templateId,
    isActive,
    name,
    html,
    subject,
    testData,
  }) {
    return this.request(`templates/${templateId}/versions`, {
      method: 'POST',
      json: {
        name,
        subject,
        html_content: html,
        plain_content: html,
        template_id: templateId,
        active: isActive ? 1 : 0,
        test_data: JSON.stringify(testData),
      },
    });
  }

  updateTemplateVersion({
    templateId,
    versionId,
    name,
    html,
    subject,
    testData,
  }) {
    return this.request(`templates/${templateId}/versions/${versionId}`, {
      method: 'PATCH',
      json: {
        name,
        subject,
        html_content: html,
        plain_content: html,
        test_data: JSON.stringify(testData),
      },
    });
  }

  deleteTemplateVersion(templateId, versionId) {
    return this.request(`templates/${templateId}/versions/${versionId}`, {
      method: 'DELETE',
    });
  }

  getTemplate(id) {
    return this.request(`templates/${id}`);
  }
}

module.exports = SendGridAPI;
