'use strict';

const yargs = require('yargs');

const create = require('./create');
const { prune } = require('./prune');
const { publish } = require('./publish');
const snapshots = require('./snapshots');
const projects = require('./config.prod.json');

const projectNames = Object.keys(projects);

process.on('unhandledRejection', (error) => {
  if (error && error.message) {
    throw error;
  } else {
    process.exit(1);
  }
});

yargs(process.argv.slice(2))
  .help()
  .version(false)
  .usage('Usage: $0 <cmd>')
  .command(
    'publish',
    'Publish new version',
    (args) =>
      args
        .option('project', {
          alias: 'p',
          type: 'string',
          describe: 'Project name',
          choices: projectNames,
          required: true,
        })
        .option('env', {
          alias: 'e',
          type: 'Environment',
          choices: ['production', 'staging'],
        })
        .option('version', { alias: 'v', type: 'string', required: true }),
    publish,
  )
  .command('create', 'Create new template.', create)
  .command('snapshots', 'Test snapshot files.', snapshots)
  .command('prune', 'Prune template versions.',  (args) =>
      args
          .option('project', {
              alias: 'p',
              type: 'string',
              describe: 'Project name',
              choices: projectNames,
              required: true,
          })
          .option('env', {
              alias: 'e',
              type: 'Environment',
              choices: ['production', 'staging'],
          }),
      prune
    )
  .parse();
