'use strict';

const fs = require('fs');
const path = require('path');
const open = require('open');
const inquirer = require('inquirer');
const { snakeCase } = require('lodash');

const templates = require('./config.prod.json');
const { updateTemplateFile } = require('./utils');

const pagesDir = path.join(__dirname, '..', 'src', 'pages');

module.exports = async () => {
  const { shouldOpenSendGrid } = await inquirer.prompt([
    {
      type: 'confirm',
      default: false,
      message: 'Create Dynamic Template in SendGrid?',
      name: 'shouldOpenSendGrid',
    },
  ]);

  if (shouldOpenSendGrid) {
    await open('https://mc.sendgrid.com/dynamic-templates/new');
  }

  let { project } = await inquirer.prompt([
    {
      type: 'list',
      message: 'Select Project',
      name: 'project',
      choices: [...Object.keys(templates), '[create new]'],
    },
  ]);

  if (project === '[create new]') {
    const { name } = await inquirer.prompt([
      {
        type: 'input',
        message: 'Enter Project',
        name: 'name',
      },
    ]);

    fs.mkdirSync(path.join(pagesDir, name));

    project = name;
  }

  const { stagingId, prodId, subject, template } = await inquirer.prompt([
    {
      type: 'input',
      name: 'template',
      message: 'Template name',
    },
    {
      type: 'input',
      name: 'subject',
      message: 'Template subject',
    },
    {
      name: 'stagingId',
      type: 'input',
      message: 'Staging Template id',
    },
    {
      name: 'prodId',
      type: 'input',
      message: 'Prod Template id',
    },
  ]);

  const templateName = `${snakeCase(template)}.html`;
  const templatePath = path.join(pagesDir, project, templateName);

  updateTemplateFile('staging', {
    [project]: { [template]: stagingId },
  });
  updateTemplateFile('prod', {
    [project]: { [template]: prodId },
  });

  fs.writeFileSync(
    templatePath,
    `---
subject: "${subject}"
---

{{> header}}


{{> footer}}
`,
  );

  console.log(`New template created in "${templatePath}".`);
};
