'use strict';


const SendGridAPI = require('./SendGridAPI');
const productionConfig = require('./config.prod.json');
const stagingConfig = require('./config.staging.json');

async function prune({ project, env }) {
  const config = env === 'production' ? productionConfig : stagingConfig;

  if (!config[project]) {
    throw Error(`Cannot find project under name "${project}".`);
  }

  try {
    const api = new SendGridAPI(project);

    for (const template in config[project]) {
      const templateId = config[project][template];

      const { versions = [] } = await api.getTemplate(templateId);
      const targetVersions = versions
        .filter(({ active }) => active === 0)
        .slice(3);

      if (targetVersions.length > 0) {
        console.log(`Found ${targetVersions.length} inactive versions for template "${template}".`);

        for (const version of targetVersions) {
          console.log(`Deleting version ${version.name}`);
          await api.deleteTemplateVersion(templateId, version.id);
        }
      }
    }
  } catch (error) {
    console.error(error.message);
    process.exit(1);
  }
}

module.exports = { prune };
