'use strict';

const fs = require('fs');
const path = require('path');
const { merge } = require('lodash');
const handlebars = require('handlebars');

const projects = require('./config.prod.json');
const lengthHelper = require('../src/helpers/length');
const equalsHelper = require('../src/helpers/equals');
const notEqualsHelper = require('../src/helpers/notEquals');
const greaterThanHelper = require('../src/helpers/greaterThan');
const andHelper = require('../src/helpers/and');

handlebars.registerHelper('length', lengthHelper);
handlebars.registerHelper('equals', equalsHelper);
handlebars.registerHelper('notEquals', notEqualsHelper);
handlebars.registerHelper('greaterThan', greaterThanHelper);
handlebars.registerHelper('and', andHelper);

function updateTemplateFile(type, overrides) {
  const configFile = `config.${type}.json`;
  const templates = require(`./${configFile}`);
  const templatePath = path.join(__dirname, `./${configFile}`);

  const value = merge({}, templates, overrides);
  const content = `${JSON.stringify(value, undefined, 2)}\n`;

  fs.writeFileSync(templatePath, content, {
    encoding: 'utf-8',
  });
}

function prepareTestData() {
  const result = {};
  const dataPath = path.join(__dirname, '..', 'src', 'data');

  const dirs = fs.readdirSync(dataPath);

  dirs.forEach((filename) => {
    const data = require(path.join(dataPath, filename));
    const key = path.parse(filename).name;
    result[key] = data;
  });

  return result;
}

function populateWithData() {
  const distDir = path.join(__dirname, '..', 'dist');
  const testData = prepareTestData();

  for (let project in projects) {
    const pagePath = path.join(distDir, project);
    const files = fs.readdirSync(pagePath);

    files.forEach((file) => {
      const filePath = path.join(pagePath, file);
      const content = fs.readFileSync(filePath, { encoding: 'utf8' });
      const template = handlebars.compile(content);
      fs.writeFileSync(filePath, template(testData));
    });
  }
}

module.exports = {
  prepareTestData,
  populateWithData,
  updateTemplateFile,
};
